@@ -71,11 +71,6 @@ class Renderer(base.Renderer):
             project = None
         return project
 
-    @property
-    def available(self):
-        """Return if the portlet is available or not."""
-        return self.links() or self.has_projects()
-
     @memoize
     def links(self):
         """ This method returns all links that should be shown in the Portlet.
@@ -90,11 +85,14 @@ class Renderer(base.Renderer):
         """
         results = []
         tracker = self.tracker_url()
+        attachments = self.attachments_url()
+        offers = self.offers_url()
         if tracker:
             results.append(dict(url=tracker, title=_(u'Issues')))
-        attachments = self.attachments_url()
         if attachments:
             results.append(dict(url=attachments, title=_(u'Attachments')))
+        if offers:
+            results.append(dict(url=offers, title=_(u'Offer')))
         if results == []:
             return None
         for res in results:
@@ -146,6 +144,20 @@ class Renderer(base.Renderer):
         if brains and len(brains) > 0:
             return self.project_url + '/project_content?type=other'
         return None
+        
+    @memoize
+    def offers_url(self):
+        """ Return the url to the offer, if available
+        """
+        if self.project is None:
+            return None
+        cfilter = {'portal_type': ('Offer',)}
+        brains = self.project.getFolderContents(cfilter)
+        if brains and len(brains) == 1:
+            return brains[0].getURL
+        elif brains and len(brains) > 1:
+            return self.project_url + '/project_content?type=offer'
+        return None
 
 
 class AddForm(base.NullAddForm):
